if __name__ == '__main__':
    def main():
        global random
        import random
        introdcution=intro()
        while True:
            inputs=choice()
            result=decision()
            print("Do you wanna play again? (Y/N)")
            ans = input().upper()
            if ans == 'Y':
                print('\n')
                continue
            else:
                print('\nHad fun playing with you')
                print('Dust me up, when you get bored')
                break

def intro():
    print("Winning Rules of the Rock Paper Scissor game as follows: \n"+ "Rock  vs Paper     -> Paper wins \n"+ 
    "Rock  vs Scissor   -> Rock wins \n"+ "Paper vs Scissor   -> Scissor wins \n")
    global Dict
    Dict={1:'Rock',2:'Paper',3:'Scissor'}     

def choice():
    print("Entry choice \n 1 for Rock, \n 2 for Paper and \n 3 for Scissor \n")
    
    global user
    user= int(input("Your choice: "))

    while user > 3 or user < 1:
        user= int(input("enter valid input: "))

    print("Your choice is: " + Dict[user])
    print("\nNow its my turn.......")
    global comp
    comp= random.randint(1, 3)
    
    while comp == user:
        comp = random.randint(1, 3)
    
    print("Comp choice is: " + Dict[comp]+'\n')
    
    print(Dict[user] + " V/s " + Dict[comp])
           

def decision():      
    if((user == 1 and comp == 2) or (user == 2 and comp == 1)):
        result = "Paper"
        print("Paper wins", end="\n")
    elif((user == 1 and comp == 3) or (user == 3 and comp == 1)):
        result = "Rock"
        print("Rock wins", end="\n")
    else:
        result = "Scissor"
        print("Scissor wins", end="\n")

    if result == Dict[user]:
        print("<== You win ==>")
    else:
        print("<== Comp win ==>")
        






if __name__ == '__main__':
    def main():
        introduction = intro()
        board = create_grid()
        pretty = printPretty(board)
        symbol_1, symbol_2 = sym()
        full = isFull(board, symbol_1, symbol_2)
        

def intro():
    print("Hello! Welcome to the classic Tic Tac Toe game!")
    print("\n")
    print("Rules: Player 1 and player 2, represented by X and O, take turns "
          "marking the spaces in a 3*3 grid."+'\n'+"The player who succeeds in placing" 
          " three of their marks in a horizontal, vertical, or diagonal row wins.")
    print("\n")
    input("Press enter to continue.")
    print("\n")

def create_grid():
    print("Here is the playboard: ")
    board = [[" ", " ", " "],
             [" ", " ", " "],
             [" ", " ", " "]]        
    return board

def sym():
    while True:
        symbol_1 = input("Player 1, do you want to be X or O? ")
        if symbol_1 == 'X' or 'O':
            break
        else:
            print('Enter proper choice')
    if symbol_1 == "X":
        symbol_2 = "O"
        print("Player 2, you are O. ")
    else:
        symbol_2 = "X"
        print("Player 2, you are X. ")
    input("Press enter to continue.")
    print("\n")
    return (symbol_1, symbol_2)



def startGamming(board, symbol_1, symbol_2, count):
    if count % 2 == 0:
        player = symbol_1
    elif count % 2 == 1:
        player = symbol_2
    print("Player "+ player + ", it is your turn. ")
    row = int(input("Pick a row:"
                    "[upper row: enter 0, middle row: enter 1, bottom row: enter 2]:"))
    column = int(input("Pick a column:"
                       "[left column: enter 0, middle column: enter 1, right column enter 2]"))

    # Check if players' selection is out of range
    while (row > 2 or row < 0) or (column > 2 or column < 0):
        outOfBoard(row, column)
        row = int(input("Pick a row[upper row:"
                        "[enter 0, middle row: enter 1, bottom row: enter 2]: "))
        column = int(input("Pick a column:"
                           "[left column: enter 0, middle column: enter 1, right column enter 2]: "))

        # Check if the square is already filled
    while (board[row][column] == symbol_1)or (board[row][column] == symbol_2):
        filled = illegal(board, symbol_1, symbol_2, row, column)
        row = int(input("Pick a row[upper row:"
                        "[enter 0, middle row: enter 1, bottom row: enter 2]: "))
        column = int(input("Pick a column:"
                            "[left column: enter 0, middle column: enter 1, right column enter 2]: "))    
        
    # Locates player's symbol on the board
    if player == symbol_1:
        board[row][column] = symbol_1
            
    else:
        board[row][column] = symbol_2
    
    return (board)

def isFull(board, symbol_1, symbol_2):
    count = 1
    winner = True
# This function check if the board is full
    while count < 10 and winner == True:
        gaming = startGamming(board, symbol_1, symbol_2, count)
        pretty = printPretty(board)
        
        if count == 9:
            print("The board is full. Game over.")
            if winner == True:
                print("There is a tie. ")

        # Check if here is a winner
        winner = isWinner(board, symbol_1, symbol_2, count)
        count += 1
    if winner == False:
        print("Game over.")
        
    # This is function gives a report 
    report(count, winner, symbol_1, symbol_2)

def outOfBoard(row, column):
    print("Out of boarder. Pick another one. ")

def printPretty(board):
    rows = len(board)
    cols = len(board)
    print("---+---+---")
    for r in range(rows):
        print(board[r][0], " |", board[r][1], "|", board[r][2])
        print("---+---+---")
    return board

def isWinner(board, symbol_1, symbol_2, count):
# This function checks if any winner is winning
    winner = True
    # Check the rows
    for row in range (0, 3):
        if (board[row][0] == board[row][1] == board[row][2] == symbol_1):
            winner = False
            print("Player " + symbol_1 + ", you won!")
   
        elif (board[row][0] == board[row][1] == board[row][2] == symbol_2):
            winner = False
            print("Player " + symbol_2 + ", you won!")
            
    # Check the columns
    for col in range (0, 3):
        if (board[0][col] == board[1][col] == board[2][col] == symbol_1):
            winner = False
            print("Player " + symbol_1 + ", you won!")
        elif (board[0][col] == board[1][col] == board[2][col] == symbol_2):
            winner = False
            print("Player " + symbol_2 + ", you won!")

    # Check the diagnoals
    if board[0][0] == board[1][1] == board[2][2] == symbol_1:
        winner = False 
        print("Player " + symbol_1 + ", you won!")

    elif board[0][0] == board[1][1] == board[2][2] == symbol_2:
        winner = False
        print("Player " + symbol_2 + ", you won!")

    elif board[0][2] == board[1][1] == board[2][0] == symbol_1:
        winner = False
        print("Player " + symbol_1 + ", you won!")

    elif board[0][2] == board[1][1] == board[2][0] == symbol_2:
        winner = False
        print("Player " + symbol_2 + ", you won!")

    return winner
    
def illegal(board, symbol_1, symbol_2, row, column):
    print("The square you picked is already filled. Pick another one.")

def report(count, winner, symbol_1, symbol_2):
    print("\n")
    input("Press enter to see the game summary. ")
    if (winner == False) and (count % 2 == 1 ):
        print("Winner : Player " + symbol_1 + ".")
    elif (winner == False) and (count % 2 == 0 ):
        print("Winner : Player " + symbol_2 + ".")
    else:
        print("There is a tie. ")

main()


if __name__ == '__main__':
    def main():
        global randrange
        global turtle
        global square,vector
        global food,snake,aim
        from random import randrange
        import turtle
        from freegames import square, vector
        food = vector(0, 0)
        snake = [vector(10, 0)]
        aim = vector(0, -10)
        turtle.setup(420, 420, 370, 0)
        turtle.hideturtle()
        turtle.tracer(False)
        turtle.listen()
        turtle.onkey(lambda: change(10, 0), 'Right')
        turtle.onkey(lambda: change(-10, 0), 'Left')
        turtle.onkey(lambda: change(0, 10), 'Up')
        turtle.onkey(lambda: change(0, -10), 'Down')
        move()
        turtle.done()
        

def change(x, y):
    """Change snake direction."""
    aim.x = x
    aim.y = y


def inside(head):
    """Return True if head inside boundaries."""
    return -200 < head.x < 190 and -200 < head.y < 190


def move():
    """Move snake forward one segment."""
    head = snake[-1].copy()
    head.move(aim)

    if not inside(head) or head in snake:
        square(head.x, head.y, 9, 'brown')
        turtle.update()
        return

    snake.append(head)
    
    if head == food:
        print('Point:', len(snake))
        food.x = randrange(-15, 15) * 10
        food.y = randrange(-15, 15) * 10
    else:
        snake.pop(0)

    turtle.clear()

    for body in snake:
        square(body.x, body.y, 9, 'black')

    square(food.x, food.y, 9, 'red')
    turtle.update()
    turtle.ontimer(move, 100)
